@@ -13,12 +13,12 @@
 #  You should have received a copy of the GNU General Public License
 #  along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
+"""gvsbuild deps print / .gv graph."""
 
 from typing import List
 
 import typer
 
-"""gvsbuild deps print / .gv graph."""
 # Verify we can import from the script directory
 try:
     import gvsbuild.utils.utils
@@ -129,7 +129,7 @@ def make_graph(
     gr_index = 0
 
     to_skip = set(skip)
-    with open(out_file, "wt", encoding="utf-8") as fo:
+    with open(out_file, "w", encoding="utf-8") as fo:
         print(f"Writing file {out_file}")
         used = set()
         fo.write("digraph gtk3dep {\n")
@@ -220,7 +220,6 @@ def deps(
         rich_help_panel="Graphing Options",
     ),
 ):
-
     Project.add_all()
     # do what's asked
     if graph:
