@@ -27,7 +27,9 @@ class Gettext(Tarball, Project):
         Project.__init__(
             self,
             "gettext",
-            archive_url="http://ftp.gnu.org/pub/gnu/gettext/gettext-0.21.tar.xz",
+            version="0.21",
+            repository="autotools-mirror/gettext",
+            archive_url="http://ftp.gnu.org/pub/gnu/gettext/gettext-{version}.tar.xz",
             hash="d20fcbb537e02dcf1383197ba05bd0734ef7bf5db06bdb241eb69b7d16b73192",
             dependencies=["win-iconv"],
             patches=[
