@@ -26,9 +26,10 @@ class Libepoxy(Tarball, Meson):
         Project.__init__(
             self,
             "libepoxy",
-            archive_url="https://github.com/anholt/libepoxy/archive/refs/tags/1.5.10.tar.gz",
+            version="1.5.10",
+            archive_url="https://github.com/anholt/libepoxy/archive/refs/tags/{version}.tar.gz",
             hash="a7ced37f4102b745ac86d6a70a9da399cc139ff168ba6b8002b4d8d43c900c15",
-            archive_filename="libepoxy-1.5.10.tar.gz",
+            archive_filename="libepoxy-{version}.tar.gz",
             dependencies=["ninja", "meson"],
         )
 
